#!/usr/bin/env python
# -*- coding: utf-8 -*-
import StringIO
import sys
import pandas as pd

class XLSParser:
    def __init__(self):
        pass

    def loadList(self, invoice_list):
        self.invoice_list = invoice_list

    def procesFile(self, file_name, output_name=None):
        xl = pd.ExcelFile(file_name)
        if len(xl.sheet_names) < 2:
            self.parseIberdrola(xl, output_name) 
        elif filter(lambda x: 'Facturacion' in x, [xl.sheet_names[1]]):
            self.parseEndesa(xl, output_name)
        else:
            raise Exception("File don't match with any suported")

    def parseEndesa(self, xl, output_name=None):
        if not output_name:
            output_name = 'output_endesa.csv'
        df1 = xl.parse(xl.sheet_names[1])
        df_obj = df1.select_dtypes(['object'])
        df1[df_obj.columns] = df_obj.apply(lambda x: x.str.strip())
        df1 = df1.iloc[:-2]
        df1.to_csv(path_or_buf=output_name, sep=';', columns=['Codigo_Fiscal_de_Factura','Importe_Total_de_la_Factura'], header=False, index=False, decimal=',')

    def parseIberdrola(self, xl, output_name=None):
        if not output_name:
            output_name='output_iberdrola.csv'
        df1 = xl.parse()
        df1.to_csv(path_or_buf=output_name, sep=';', columns=['NUMFACTRUA','IMPORTE EUR'], header=False, index=False, decimal=',')

# vim: et ts=4 sw=4



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import StringIO
import csv
import sys

class CSVParser:
    def __init__(self):
        self.invoice_list = []

    def loadCSV(self, file_name):
        with open(file_name, 'r') as csvfile:
            reader = csv.reader(csvfile, delimiter=';')
            for row in reader:
                self.invoice_list.append(row)
    
    def loadList(self, invoice_list):
        self.invoice_list = invoice_list

    def procesFile(self):
        if not self.invoice_list:
            raise Exception("No invoice loaded. Please, load an invoice list or a file before use procesFile")
        i = 0
        while i<len(self.invoice_list):
            if filter(lambda x: 'SOCIEDAD: 0703-UFD' in x, self.invoice_list[i]):
                return self.parseUFD()
            if filter(lambda x: 'No trobada' in x, self.invoice_list[i]):
                return self.parseERP()
            i += 1

    def parseUFD(self):
        i = 0
        dist_line = []
        while i<len(self.invoice_list):
            if len(self.invoice_list[i]) == 4:
                dist_line.append([self.invoice_list[i][1],self.invoice_list[i][3]])
            i += 1
        return dist_line[1:]

    def parseERP(self):
        i = 0
        dist_line = []
        while i<len(self.invoice_list):
            if len(self.invoice_list[i]) == 3:
                dist_line.append([self.invoice_list[i][0],self.invoice_list[i][1].replace('.',',')])
            i += 1
        return dist_line
# vim: et ts=4 sw=4



from setuptools import setup

setup(
    name='distri-remesa-parser',
    version='0.1.1',
    description='A python library to parser payment order files with related invoices sended by the spanish "Distribuidoras" to the "Comercializadoras',
    url='https://github.com/Som-Energia/distri-remesa-parser',
    author='oriolpiera',
    author_email='oriol.piera@somenergia.coop',
    license='GNU General Public License v3 or later (GPLv3+)',
    packages=['distriremesaparser'],
    zip_safe=False,
    test_suite='tests',
)
